pub enum EngineError {
InvalidCharacterInRegex,
OperationTimeOutError,
AutomatonShouldBeDeterministic,
AutomatonHasTooManyStates,
RegexSyntaxError(String),
TooMuchTerms(usize, usize),
ConditionInvalidRange,
ConditionIndexOutOfBound,
TokenError(TokenError),
}Expand description
An error thrown by the engine.
Variants
InvalidCharacterInRegex
Invalid character used in regex.
OperationTimeOutError
The operation took too much time.
AutomatonShouldBeDeterministic
The given automaton should be deterministic.
AutomatonHasTooManyStates
The automaton has too many states.
RegexSyntaxError(String)
The regular expression can not be parsed.
TooMuchTerms(usize, usize)
Too many terms are used in the operation.
ConditionInvalidRange
The provided range can not be built from the spanning set.
ConditionIndexOutOfBound
The provided index is out of bound of the condition.
TokenError(TokenError)
There is an error with one of the token.
Implementations
Sourceimpl EngineError
impl EngineError
Sourcepub fn is_server_error(&self) -> bool
pub fn is_server_error(&self) -> bool
Determine if the error is a server error. A server error should not be shown to the end user.